/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GetCoreProjectRequest, GetCoreProjectResponseOK } from "./types/core/project";
import { GetCoreProjectsRequest, GetCoreProjectsResponseOK } from "./types/core/project";
import { GetCoreTeamRequest, GetCoreTeamResponseOK } from "./types/core/team";
import { GetAllCoreTeamsRequest, GetAllCoreTeamsResponseOK } from "./types/core/team";
import { GetCoreTeamMembersWithExtendedPropertiesRequest, GetCoreTeamMembersWithExtendedPropertiesResponseOK } from "./types/core/team";
import { GetCoreTeamsRequest, GetCoreTeamsResponseOK } from "./types/core/team";
import { GetGitCommitRequest, GetGitCommitResponseOK } from "./types/git/commit";
import { GetGitChangesRequest, GetGitChangesResponseOK } from "./types/git/commit";
import { GetGitCommitsRequest, GetGitCommitsResponseOK } from "./types/git/commit";
import { GetGitPushCommitsRequest, GetGitPushCommitsResponseOK } from "./types/git/commit";
import { GetGitRepositoryRequest, GetGitRepositoryResponseOK } from "./types/git/repository";
import { GetGitRepositoriesRequest, GetGitRepositoriesResponseOK } from "./types/git/repository";
import { GetGraphUserRequest, GetGraphUserResponseOK } from "./types/graph/user";
import { GetGraphUsersRequest, GetGraphUsersResponseOK } from "./types/graph/user";
import { CreateWikiRequest, CreateWikiResponseOK } from "./types/wiki";
import { GetWikisRequest, GetWikisResponseOK } from "./types/wiki";
import { DeleteWikiRequest, DeleteWikiResponseOK } from "./types/wiki";
import { GetWikiRequest, GetWikiResponseOK } from "./types/wiki";
import { EditWikiRequest, EditWikiResponseOK } from "./types/wiki";
import { BaseApiCore, Headers, Response, ErrorStrategyOptionType, PlatformImplementation } from "@managed-api/commons-core";
import { CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyOption } from "./errorStrategy";
import { ErrorStrategyBuilder } from "./builders/errorStrategy";
export interface AzureDevopsApiCoreOptions extends ErrorStrategyOption {
}
declare type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class AzureDevopsApiCore extends BaseApiCore {
    private options?;
    Core: CoreGroup;
    Git: GitGroup;
    Graph: GraphGroup;
    Wiki: WikiGroup;
    All: AllGroup;
    constructor(options?: AzureDevopsApiCoreOptions | undefined);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private Core;
    private Git;
    private Graph;
    private Wiki;
    constructor(Core: CoreGroup, Git: GitGroup, Graph: GraphGroup, Wiki: WikiGroup);
    /**
     * Get project with the specified id or name, optionally including capabilities.
     * Alternative usage: Core.Project.getProject
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/projects/get?view=azure-devops-rest-7.2
     * @param options Request options.
     */
    getCoreProject<T = GetCoreProjectResponseOK>(options: GetCoreProjectRequest): Promise<GetCoreProjectResponseOK | T>;
    /**
     * Get all projects in the organization that the authenticated user has access to.
     * Alternative usage: Core.Project.getProjects
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/projects/list?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getCoreProjects<T = GetCoreProjectsResponseOK>(options: GetCoreProjectsRequest): Promise<GetCoreProjectsResponseOK | T>;
    /**
     * Get a specific team.
     * Alternative usage: Core.Team.getTeam
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getCoreTeam<T = GetCoreTeamResponseOK>(options: GetCoreTeamRequest): Promise<GetCoreTeamResponseOK | T>;
    /**
     * Get a list of all teams.
     * Alternative usage: Core.Team.getAllTeams
     * Documentation: https://dev.azure.com/{organization}/_apis/teams?api-version=7.2-preview.3
     * @param options Request options.
     */
    getAllCoreTeams<T = GetAllCoreTeamsResponseOK>(options: GetAllCoreTeamsRequest): Promise<GetAllCoreTeamsResponseOK | T>;
    /**
     * Get a list of members for a specific team.
     * Alternative usage: Core.Team.getMembersWithExtendedProperties
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get-team-members-with-extended-properties?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getCoreTeamMembersWithExtendedProperties<T = GetCoreTeamMembersWithExtendedPropertiesResponseOK>(options: GetCoreTeamMembersWithExtendedPropertiesRequest): Promise<GetCoreTeamMembersWithExtendedPropertiesResponseOK | T>;
    /**
     * Get a list of teams.
     * Alternative usage: Core.Team.getTeams
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get-teams?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getCoreTeams<T = GetCoreTeamsResponseOK>(options: GetCoreTeamsRequest): Promise<GetCoreTeamsResponseOK | T>;
    /**
     * Retrieve a particular commit.
     * Alternative usage: Git.Commit.getCommit
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getGitCommit<T = GetGitCommitResponseOK>(options: GetGitCommitRequest): Promise<GetGitCommitResponseOK | T>;
    /**
     * Retrieve changes for a particular commit.
     * Alternative usage: Git.Commit.getChanges
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-changes?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getGitChanges<T = GetGitChangesResponseOK>(options: GetGitChangesRequest): Promise<GetGitChangesResponseOK | T>;
    /**
     * Retrieve git commits for a project
     * Alternative usage: Git.Commit.getCommits
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-commits?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getGitCommits<T = GetGitCommitsResponseOK>(options: GetGitCommitsRequest): Promise<GetGitCommitsResponseOK | T>;
    /**
     * Retrieve a list of commits associated with a particular push.
     * Alternative usage: Git.Commit.getPushCommits
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-push-commits?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getGitPushCommits<T = GetGitPushCommitsResponseOK>(options: GetGitPushCommitsRequest): Promise<GetGitPushCommitsResponseOK | T>;
    /**
     * Retrieve a git repository.
     * Alternative usage: Git.Repository.getRepository
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/repositories/get-repository?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getGitRepository<T = GetGitRepositoryResponseOK>(options: GetGitRepositoryRequest): Promise<GetGitRepositoryResponseOK | T>;
    /**
     * Retrieve git repositories.
     * Alternative usage: Git.Repository.getRepositories
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/repositories/get-repository?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getGitRepositories<T = GetGitRepositoriesResponseOK>(options: GetGitRepositoriesRequest): Promise<GetGitRepositoriesResponseOK | T>;
    /**
     * Get a user by its descriptor.
     * Alternative usage: Graph.User.getUser
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/graph/users/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getGraphUser<T = GetGraphUserResponseOK>(options: GetGraphUserRequest): Promise<GetGraphUserResponseOK | T>;
    /**
  * Get a list of all users in a given scope.
  
  Since the list of users may be large, results are returned in pages of users.  If there are more results
   than can be returned in a single page, the result set will contain a continuation token for retrieval of the
   next set of results.
  * Alternative usage: Graph.User.getUsers
  * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/graph/users/list?view=azure-devops-rest-7.2&tabs=HTTP
  * @param options Request options.
  */
    getGraphUsers<T = GetGraphUsersResponseOK>(options: GetGraphUsersRequest): Promise<GetGraphUsersResponseOK | T>;
    /**
     * Creates the wiki resource.
     * Alternative usage: Wiki.createWiki
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/create?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    createWiki<T = CreateWikiResponseOK>(options: CreateWikiRequest): Promise<CreateWikiResponseOK | T>;
    /**
     * Gets all wikis in a project or collection.
     * Alternative usage: Wiki.getWikis
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/list?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getWikis<T = GetWikisResponseOK>(options: GetWikisRequest): Promise<GetWikisResponseOK | T>;
    /**
     * Deletes the wiki corresponding to the wiki ID or wiki name provided.
     * Alternative usage: Wiki.deleteWiki
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/delete?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    deleteWiki<T = DeleteWikiResponseOK>(options: DeleteWikiRequest): Promise<DeleteWikiResponseOK | T>;
    /**
     * Gets the wiki corresponding to the wiki ID or wiki name provided.
     * Alternative usage: Wiki.getWiki
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getWiki<T = GetWikiResponseOK>(options: GetWikiRequest): Promise<GetWikiResponseOK | T>;
    /**
     * Updates the wiki corresponding to the wiki ID or wiki name provided using the update parameters.
     * Alternative usage: Wiki.editWiki
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/update?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    editWiki<T = EditWikiResponseOK>(options: EditWikiRequest): Promise<EditWikiResponseOK | T>;
}
declare class CoreGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Project: CoreProjectGroup;
    Team: CoreTeamGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class CoreProjectGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get project with the specified id or name, optionally including capabilities.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/projects/get?view=azure-devops-rest-7.2
     * @param options Request options.
     */
    getProject<T = GetCoreProjectResponseOK>(options: GetCoreProjectRequest): Promise<GetCoreProjectResponseOK | T>;
    /**
     * Get all projects in the organization that the authenticated user has access to.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/projects/list?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getProjects<T = GetCoreProjectsResponseOK>(options: GetCoreProjectsRequest): Promise<GetCoreProjectsResponseOK | T>;
}
declare class CoreTeamGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get a specific team.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getTeam<T = GetCoreTeamResponseOK>(options: GetCoreTeamRequest): Promise<GetCoreTeamResponseOK | T>;
    /**
     * Get a list of all teams.
     * Documentation: https://dev.azure.com/{organization}/_apis/teams?api-version=7.2-preview.3
     * @param options Request options.
     */
    getAllTeams<T = GetAllCoreTeamsResponseOK>(options: GetAllCoreTeamsRequest): Promise<GetAllCoreTeamsResponseOK | T>;
    /**
     * Get a list of members for a specific team.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get-team-members-with-extended-properties?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getMembersWithExtendedProperties<T = GetCoreTeamMembersWithExtendedPropertiesResponseOK>(options: GetCoreTeamMembersWithExtendedPropertiesRequest): Promise<GetCoreTeamMembersWithExtendedPropertiesResponseOK | T>;
    /**
     * Get a list of teams.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/core/teams/get-teams?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getTeams<T = GetCoreTeamsResponseOK>(options: GetCoreTeamsRequest): Promise<GetCoreTeamsResponseOK | T>;
}
declare class GitGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Commit: GitCommitGroup;
    Repository: GitRepositoryGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class GitCommitGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Retrieve a particular commit.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getCommit<T = GetGitCommitResponseOK>(options: GetGitCommitRequest): Promise<GetGitCommitResponseOK | T>;
    /**
     * Retrieve changes for a particular commit.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-changes?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getChanges<T = GetGitChangesResponseOK>(options: GetGitChangesRequest): Promise<GetGitChangesResponseOK | T>;
    /**
     * Retrieve git commits for a project
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-commits?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getCommits<T = GetGitCommitsResponseOK>(options: GetGitCommitsRequest): Promise<GetGitCommitsResponseOK | T>;
    /**
     * Retrieve a list of commits associated with a particular push.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/commits/get-push-commits?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getPushCommits<T = GetGitPushCommitsResponseOK>(options: GetGitPushCommitsRequest): Promise<GetGitPushCommitsResponseOK | T>;
}
declare class GitRepositoryGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Retrieve a git repository.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/repositories/get-repository?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getRepository<T = GetGitRepositoryResponseOK>(options: GetGitRepositoryRequest): Promise<GetGitRepositoryResponseOK | T>;
    /**
     * Retrieve git repositories.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/git/repositories/get-repository?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getRepositories<T = GetGitRepositoriesResponseOK>(options: GetGitRepositoriesRequest): Promise<GetGitRepositoriesResponseOK | T>;
}
declare class GraphGroup {
    private implementation;
    private getGlobalErrorStrategy;
    User: GraphUserGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
}
declare class GraphUserGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get a user by its descriptor.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/graph/users/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getUser<T = GetGraphUserResponseOK>(options: GetGraphUserRequest): Promise<GetGraphUserResponseOK | T>;
    /**
  * Get a list of all users in a given scope.
  
  Since the list of users may be large, results are returned in pages of users.  If there are more results
   than can be returned in a single page, the result set will contain a continuation token for retrieval of the
   next set of results.
  * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/graph/users/list?view=azure-devops-rest-7.2&tabs=HTTP
  * @param options Request options.
  */
    getUsers<T = GetGraphUsersResponseOK>(options: GetGraphUsersRequest): Promise<GetGraphUsersResponseOK | T>;
}
declare class WikiGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Creates the wiki resource.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/create?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    createWiki<T = CreateWikiResponseOK>(options: CreateWikiRequest): Promise<CreateWikiResponseOK | T>;
    /**
     * Gets all wikis in a project or collection.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/list?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getWikis<T = GetWikisResponseOK>(options: GetWikisRequest): Promise<GetWikisResponseOK | T>;
    /**
     * Deletes the wiki corresponding to the wiki ID or wiki name provided.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/delete?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    deleteWiki<T = DeleteWikiResponseOK>(options: DeleteWikiRequest): Promise<DeleteWikiResponseOK | T>;
    /**
     * Gets the wiki corresponding to the wiki ID or wiki name provided.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/get?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    getWiki<T = GetWikiResponseOK>(options: GetWikiRequest): Promise<GetWikiResponseOK | T>;
    /**
     * Updates the wiki corresponding to the wiki ID or wiki name provided using the update parameters.
     * Documentation: https://learn.microsoft.com/en-us/rest/api/azure/devops/wiki/wikis/update?view=azure-devops-rest-7.2&tabs=HTTP
     * @param options Request options.
     */
    editWiki<T = EditWikiResponseOK>(options: EditWikiRequest): Promise<EditWikiResponseOK | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map