/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { TeamProjectAsResponse } from "../../definitions/TeamProjectAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { TeamProjectReference2AsResponse } from "../../definitions/TeamProjectReference2AsResponse";
export interface GetCoreProjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    projectId: string;
    /**
     * Include capabilities (such as source control) in the team project result (default: false).
     */
    includeCapabilities?: boolean;
    /**
     * Search within renamed projects (that had such name in the past).
     */
    includeHistory?: boolean;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.4' to use this version of the api.
     */
    "api-version": "7.2-preview.4";
}
declare type GetCoreProjectResponseOKType = TeamProjectAsResponse;
export interface GetCoreProjectResponseOK extends GetCoreProjectResponseOKType {
}
export declare type GetCoreProjectResponseError = undefined;
export interface GetCoreProjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * Filter on team projects in a specific team project state (default: WellFormed).
     */
    stateFilter?: "deleting" | "new" | "wellFormed" | "createPending" | "all" | "unchanged" | "deleted";
    $top?: number;
    $skip?: number;
    /**
     * Pointer that shows how many projects already been fetched.
     */
    continuationToken?: number;
    getDefaultTeamImageUrl?: boolean;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.4' to use this version of the api.
     */
    "api-version": "7.2-preview.4";
}
declare type GetCoreProjectsResponseOKType = Array<TeamProjectReference2AsResponse>;
export interface GetCoreProjectsResponseOK extends GetCoreProjectsResponseOKType {
}
export declare type GetCoreProjectsResponseError = undefined;
export {};
//# sourceMappingURL=project.d.ts.map