/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { WebApiTeamAsResponse } from "../../definitions/WebApiTeamAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { TeamMemberAsResponse } from "../../definitions/TeamMemberAsResponse";
export interface GetCoreTeamRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * The name or ID (GUID) of the team project containing the team.
     */
    projectId: string;
    /**
     * The name or ID (GUID) of the team.
     */
    teamId: string;
    /**
     * A value indicating whether or not to expand Identity information in the result WebApiTeam object.
     */
    $expandIdentity?: boolean;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.3' to use this version of the api.
     */
    "api-version": "7.2-preview.3";
}
declare type GetCoreTeamResponseOKType = WebApiTeamAsResponse;
export interface GetCoreTeamResponseOK extends GetCoreTeamResponseOKType {
}
export declare type GetCoreTeamResponseError = undefined;
export interface GetAllCoreTeamsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * If true, then return all teams requesting user is member. Otherwise return all teams user has read access.
     */
    $mine?: boolean;
    /**
     * Maximum number of teams to return.
     */
    $top?: number;
    /**
     * Number of teams to skip.
     */
    $skip?: number;
    /**
     * A value indicating whether or not to expand Identity information in the result WebApiTeam object.
     */
    $expandIdentity?: boolean;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.3' to use this version of the api.
     */
    "api-version": "7.2-preview.3";
}
declare type GetAllCoreTeamsResponseOKType = Array<WebApiTeamAsResponse>;
export interface GetAllCoreTeamsResponseOK extends GetAllCoreTeamsResponseOKType {
}
export declare type GetAllCoreTeamsResponseError = undefined;
export interface GetCoreTeamMembersWithExtendedPropertiesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * The name or ID (GUID) of the team project the team belongs to.
     */
    projectId: string;
    /**
     * The name or ID (GUID) of the team .
     */
    teamId: string;
    $top?: number;
    $skip?: number;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.2' to use this version of the api.
     */
    "api-version": "7.2-preview.2";
}
declare type GetCoreTeamMembersWithExtendedPropertiesResponseOKType = Array<TeamMemberAsResponse>;
export interface GetCoreTeamMembersWithExtendedPropertiesResponseOK extends GetCoreTeamMembersWithExtendedPropertiesResponseOKType {
}
export declare type GetCoreTeamMembersWithExtendedPropertiesResponseError = undefined;
export interface GetCoreTeamsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    projectId: string;
    /**
     * If true return all the teams requesting user is member, otherwise return all the teams user has read access.
     */
    $mine?: boolean;
    /**
     * Maximum number of teams to return.
     */
    $top?: number;
    /**
     * Number of teams to skip.
     */
    $skip?: number;
    /**
     * A value indicating whether or not to expand Identity information in the result WebApiTeam object.
     */
    $expandIdentity?: boolean;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.3' to use this version of the api.
     */
    "api-version": "7.2-preview.3";
}
declare type GetCoreTeamsResponseOKType = Array<WebApiTeamAsResponse>;
export interface GetCoreTeamsResponseOK extends GetCoreTeamsResponseOKType {
}
export declare type GetCoreTeamsResponseError = undefined;
export {};
//# sourceMappingURL=team.d.ts.map