/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GitCommitAsResponse } from "../../definitions/GitCommitAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { GitCommitChangesAsResponse } from "../../definitions/GitCommitChangesAsResponse";
import { GitCommitRefAsResponse } from "../../definitions/GitCommitRefAsResponse";
export interface GetGitCommitRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * The id of the commit.
     */
    commitId: string;
    /**
     * The id or friendly name of the repository. To use the friendly name, projectId must also be specified.
     */
    repositoryId: string;
    /**
     * Project ID or project name
     */
    project: string;
    /**
     * The number of changes to include in the result.
     */
    changeCount?: number;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.2' to use this version of the api.
     */
    "api-version": "7.2-preview.2";
}
declare type GetGitCommitResponseOKType = GitCommitAsResponse;
export interface GetGitCommitResponseOK extends GetGitCommitResponseOKType {
}
export declare type GetGitCommitResponseError = undefined;
export interface GetGitChangesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * The id of the commit.
     */
    commitId: string;
    /**
     * The id or friendly name of the repository. To use the friendly name, projectId must also be specified.
     */
    repositoryId: string;
    /**
     * Project ID or project name
     */
    project: string;
    /**
     * The maximum number of changes to return.
     */
    top?: number;
    /**
     * The number of changes to skip.
     */
    skip?: number;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.1' to use this version of the api.
     */
    "api-version": "7.2-preview.1";
}
declare type GetGitChangesResponseOKType = GitCommitChangesAsResponse;
export interface GetGitChangesResponseOK extends GetGitChangesResponseOKType {
}
export declare type GetGitChangesResponseError = undefined;
export interface GetGitCommitsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * The id or friendly name of the repository. To use the friendly name, projectId must also be specified.
     */
    repositoryId: string;
    /**
     * Project ID or project name
     */
    project: string;
    /**
     * Version of the API to use. This should be set to '7.2-preview.2' to use this version of the api.
     */
    "api-version": "7.2-preview.2";
    /**
     * Number of entries to skip
     */
    $skip?: number;
    /**
     * Maximum number of entries to retrieve
     */
    $top?: number;
    /**
     * Alias or display name of the author
     */
    author?: string;
    /**
     * Version string identifier (name of tag/branch, SHA1 of commit)
     */
    "compareVersion.version"?: string;
    /**
     * Version options - Specify additional modifiers to version (e.g Previous)
     */
    "compareVersion.versionOptions"?: "None" | "Previous" | "FirstParent";
    /**
     * Version type (branch, tag, or commit). Determines how Id is interpreted
     */
    "compareVersion.versionType"?: "Branch" | "Tag" | "Commit";
    /**
     * Only applies when an itemPath is specified. This determines whether to exclude delete entries of the specified path.
     */
    excludeDeletes?: boolean;
    /**
     * If provided, a lower bound for filtering commits alphabetically
     */
    fromCommitId?: string;
    /**
     * If provided, only include history entries created after this date (string)
     */
    fromDate?: string;
    /**
     * What Git history mode should be used. This only applies to the search criteria when Ids = null and an itemPath is specified.
     */
    historyMode?: "SimplifiedHistory" | "FirstParent";
    /**
     * If provided, specifies the exact commit ids of the commits to fetch. May not be combined with other parameters.
     */
    ids?: Array<string>;
    /**
     * Whether to include the _links field on the shallow references
     */
    includeLinks?: boolean;
    /**
     * Whether to include the push information
     */
    includePushData?: boolean;
    /**
     * Whether to include the image Url for committers and authors
     */
    includeUserImageUrl?: boolean;
    /**
     * Whether to include linked work items
     */
    includeWorkItems?: boolean;
    /**
     * Path of item to search under
     */
    itemPath?: string;
    /**
     * Version string identifier (name of tag/branch, SHA1 of commit)
     */
    "itemVersion.version"?: string;
    /**
     * Version options - Specify additional modifiers to version (e.g Previous)
     */
    "itemVersion.versionOptions"?: "None" | "Previous" | "FirstParent";
    /**
     * Version type (branch, tag, or commit). Determines how Id is interpreted
     */
    "itemVersion.versionType"?: "Branch" | "Tag" | "Commit";
    /**
     * If enabled, this option will ignore the itemVersion and compareVersion parameters
     */
    showOldestCommitsFirst?: boolean;
    /**
     * If provided, an upper bound for filtering commits alphabetically
     */
    toCommitId?: string;
    /**
     * If provided, only include history entries created before this date (string)
     */
    toDate?: string;
    /**
     * Alias or display name of the committer
     */
    user?: string;
}
declare type GetGitCommitsResponseOKType = Array<GitCommitRefAsResponse>;
export interface GetGitCommitsResponseOK extends GetGitCommitsResponseOKType {
}
export declare type GetGitCommitsResponseError = undefined;
export interface GetGitPushCommitsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * The id or friendly name of the repository. To use the friendly name, projectId must also be specified.
     */
    repositoryId: string;
    /**
     * Project ID or project name
     */
    project: string;
    /**
     * The id of the push.
     */
    pushId: number;
    /**
     * The maximum number of commits to return ("get the top x commits").
     */
    top?: number;
    /**
     * The number of commits to skip.
     */
    skip?: number;
    /**
     * Set to false to avoid including REST Url links for resources. Defaults to true.
     */
    includeLinks?: boolean;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.2' to use this version of the api.
     */
    "api-version": "7.2-preview.2";
}
declare type GetGitPushCommitsResponseOKType = Array<GitCommitRefAsResponse>;
export interface GetGitPushCommitsResponseOK extends GetGitPushCommitsResponseOKType {
}
export declare type GetGitPushCommitsResponseError = undefined;
export {};
//# sourceMappingURL=commit.d.ts.map