/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GraphUserAsResponse } from "../../definitions/GraphUserAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetGraphUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * The descriptor of the desired user.
     */
    userDescriptor: string;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.1' to use this version of the api.
     */
    "api-version": "7.2-preview.1";
}
declare type GetGraphUserResponseOKType = GraphUserAsResponse;
export interface GetGraphUserResponseOK extends GetGraphUserResponseOKType {
}
export declare type GetGraphUserResponseError = undefined;
export interface GetGraphUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * A comma separated list of user subject subtypes to reduce the retrieved results, e.g. msa’, ‘aad’, ‘svc’ (service identity), ‘imp’ (imported identity), etc.
     */
    subjectTypes?: string;
    /**
     * An opaque data blob that allows the next page of data to resume immediately after where the previous page ended. The only reliable way to know if there is more data left is the presence of a continuation token.
     */
    continuationToken?: string;
    /**
     * Specify a non-default scope (collection, project) to search for users.
     */
    scopeDescriptor?: string;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.1' to use this version of the api.
     */
    "api-version": "7.2-preview.1";
}
declare type GetGraphUsersResponseOKType = Array<GraphUserAsResponse>;
export interface GetGraphUsersResponseOK extends GetGraphUsersResponseOKType {
}
export declare type GetGraphUsersResponseError = undefined;
export {};
//# sourceMappingURL=user.d.ts.map