/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { WikiCreateParametersV2 } from "../definitions/WikiCreateParametersV2";
import { WikiV2AsResponse } from "../definitions/WikiV2AsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { WikiUpdateParameters } from "../definitions/WikiUpdateParameters";
export interface CreateWikiRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * Project ID or project name
     */
    project: string;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.2' to use this version of the api.
     */
    "api-version": "7.2-preview.2";
    body: WikiCreateParametersV2;
}
declare type CreateWikiResponseOKType = WikiV2AsResponse;
export interface CreateWikiResponseOK extends CreateWikiResponseOKType {
}
export declare type CreateWikiResponseError = undefined;
export interface GetWikisRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * Project ID or project name
     */
    project: string;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.2' to use this version of the api.
     */
    "api-version": "7.2-preview.2";
}
declare type GetWikisResponseOKType = Array<WikiV2AsResponse>;
export interface GetWikisResponseOK extends GetWikisResponseOKType {
}
export declare type GetWikisResponseError = undefined;
export interface DeleteWikiRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * Wiki ID or wiki name.
     */
    wikiIdentifier: string;
    /**
     * Project ID or project name
     */
    project: string;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.2' to use this version of the api.
     */
    "api-version": "7.2-preview.2";
}
declare type DeleteWikiResponseOKType = WikiV2AsResponse;
export interface DeleteWikiResponseOK extends DeleteWikiResponseOKType {
}
export declare type DeleteWikiResponseError = undefined;
export interface GetWikiRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * Wiki ID or wiki name.
     */
    wikiIdentifier: string;
    /**
     * Project ID or project name
     */
    project: string;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.2' to use this version of the api.
     */
    "api-version": "7.2-preview.2";
}
declare type GetWikiResponseOKType = WikiV2AsResponse;
export interface GetWikiResponseOK extends GetWikiResponseOKType {
}
export declare type GetWikiResponseError = undefined;
export interface EditWikiRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the Azure DevOps organization.
     */
    organization: string;
    /**
     * Wiki ID or wiki name.
     */
    wikiIdentifier: string;
    /**
     * Project ID or project name
     */
    project: string;
    /**
     * Version of the API to use.  This should be set to '7.2-preview.2' to use this version of the api.
     */
    "api-version": "7.2-preview.2";
    body: WikiUpdateParameters;
}
declare type EditWikiResponseOKType = WikiV2AsResponse;
export interface EditWikiResponseOK extends EditWikiResponseOKType {
}
export declare type EditWikiResponseError = undefined;
export {};
//# sourceMappingURL=wiki.d.ts.map